@@ -12,6 +12,8 @@
 #define HAVE_STRING_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -20,7 +22,7 @@
 #define SIZEOF_LONG 4
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
-#define SIZEOF_OFF_T 4
+#define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 4
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
@@ -51,7 +53,10 @@
 #define HAVE_MEMORY_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_UTIME_H 1
+#define HAVE_NETINET_IN_SYSTM_H 1
 #define HAVE_FLOAT_H 1
+#define HAVE_IEEEFP_H 1
+#define HAVE_PTHREAD_H 1
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
 #define HAVE_STRUCT_STAT_ST_BLOCKS 1
@@ -62,6 +67,8 @@
 #define RETSIGTYPE void
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
+#define HAVE_FSEEKO 1
+#define HAVE_FTELLO 1
 #define HAVE_DUP2 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKDIR 1
@@ -73,9 +80,9 @@
 #define HAVE_STRSTR 1
 #define HAVE_STRTOUL 1
 #define HAVE_VSNPRINTF 1
-#define HAVE_ISINF 1
 #define HAVE_ISNAN 1
 #define HAVE_FINITE 1
+#define HAVE_ISINF 1
 #define HAVE_HYPOT 1
 #define HAVE_ACOSH 1
 #define HAVE_ERF 1
@@ -85,6 +92,7 @@
 #define HAVE_WAITPID 1
 #define HAVE_CHROOT 1
 #define HAVE_FSYNC 1
+#define HAVE_GETCWD 1
 #define HAVE_TRUNCATE 1
 #define HAVE_TIMES 1
 #define HAVE_UTIMES 1
@@ -93,7 +101,9 @@
 #define HAVE_SYMLINK 1
 #define HAVE_READLINK 1
 #define HAVE_SETEUID 1
+#define HAVE_SETREUID 1
 #define HAVE_SETEGID 1
+#define HAVE_SETREGID 1
 #define HAVE_PAUSE 1
 #define HAVE_LCHOWN 1
 #define HAVE_GETPGRP 1
@@ -114,6 +124,8 @@
 #define HAVE_COSH 1
 #define HAVE_SINH 1
 #define HAVE_TANH 1
+#define HAVE_SETUID 1
+#define HAVE_SETGID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
@@ -122,6 +134,7 @@
 #define FILE_COUNT _r
 #define FILE_READPTR _p
 #define NEED_IO_SEEK_BETWEEN_RW 1
+#define HUGE_ST_INO 1
 #define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
 #define DLEXT ".so"
